@@ -10,6 +10,8 @@ insDoc(aux1, gLnk("R", "ABCapHeight", "vars/Time-Dependent.html#ABCapHeight"))
 insDoc(aux1, gLnk("R", "ABShape", "vars/Time-Dependent.html#ABShape"))
 insDoc(aux1, gLnk("R", "AbsorbingBoundaries", "vars/Time-Dependent.html#AbsorbingBoundaries"))
 insDoc(aux1, gLnk("R", "ABWidth", "vars/Time-Dependent.html#ABWidth"))
+insDoc(aux1, gLnk("R", "ACBN0RotationallyInvariant", "vars/Hamiltonian.html#ACBN0RotationallyInvariant"))
+insDoc(aux1, gLnk("R", "ACBN0Screening", "vars/Hamiltonian.html#ACBN0Screening"))
 insDoc(aux1, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
 insDoc(aux1, gLnk("R", "AnimationMultiFiles", "vars/Utilities.html#AnimationMultiFiles"))
 insDoc(aux1, gLnk("R", "AnimationSampling", "vars/Utilities.html#AnimationSampling"))
@@ -18,7 +20,7 @@ insDoc(aux1, gLnk("R", "AONormalize", "vars/Hamiltonian.html#AONormalize"))
 insDoc(aux1, gLnk("R", "AOSubmeshForPeriodic", "vars/Hamiltonian.html#AOSubmeshForPeriodic"))
 insDoc(aux1, gLnk("R", "AOThreshold", "vars/Hamiltonian.html#AOThreshold"))
 insDoc(aux1, gLnk("R", "AOTruncation", "vars/Hamiltonian.html#AOTruncation"))
-insDoc(aux1, gLnk("R", "ArpackInitialTolerance", "vars/SCF.html#ArpackInitialTolerance"))
+insDoc(aux1, gLnk("R", "ArnoldiOrthogonalization", "vars/Time-Dependent.html#ArnoldiOrthogonalization"))
 insDoc(aux1, gLnk("R", "AtomsMagnetDirection", "vars/SCF.html#AtomsMagnetDirection"))
 insDoc(aux1, gLnk("R", "AxisType", "vars/Utilities.html#AxisType"))
 aux1 = insFld(aux0, gFld("B", "javascript:parent.op()"))
@@ -62,16 +64,10 @@ insDoc(aux1, gLnk("R", "CasidaSpectrumRotationMatrix", "vars/Utilities.html#Casi
 insDoc(aux1, gLnk("R", "CasidaTheoryLevel", "vars/Linear_Response.html#CasidaTheoryLevel"))
 insDoc(aux1, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#CasidaTransitionDensities"))
 insDoc(aux1, gLnk("R", "CasidaWeightThreshold", "vars/Linear_Response.html#CasidaWeightThreshold"))
+insDoc(aux1, gLnk("R", "CGAdditionalTerms", "vars/SCF.html#CGAdditionalTerms"))
+insDoc(aux1, gLnk("R", "CGDirection", "vars/SCF.html#CGDirection"))
+insDoc(aux1, gLnk("R", "CGOrthogonalizeAll", "vars/SCF.html#CGOrthogonalizeAll"))
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
-insDoc(aux1, gLnk("R", "ComplexScaling", "vars/Hamiltonian.html#ComplexScaling"))
-insDoc(aux1, gLnk("R", "ComplexScalingAlpha", "vars/Hamiltonian.html#ComplexScalingAlpha"))
-insDoc(aux1, gLnk("R", "ComplexScalingAlphaLeft", "vars/Hamiltonian.html#ComplexScalingAlphaLeft"))
-insDoc(aux1, gLnk("R", "ComplexScalingLocalizationRadius", "vars/Hamiltonian.html#ComplexScalingLocalizationRadius"))
-insDoc(aux1, gLnk("R", "ComplexScalingLocalizationThreshold", "vars/Hamiltonian.html#ComplexScalingLocalizationThreshold"))
-insDoc(aux1, gLnk("R", "ComplexScalingLocalizedStates", "vars/Hamiltonian.html#ComplexScalingLocalizedStates"))
-insDoc(aux1, gLnk("R", "ComplexScalingPenalizationFactor", "vars/Hamiltonian.html#ComplexScalingPenalizationFactor"))
-insDoc(aux1, gLnk("R", "ComplexScalingRotateSpectrum", "vars/Hamiltonian.html#ComplexScalingRotateSpectrum"))
-insDoc(aux1, gLnk("R", "ComplexScalingTheta", "vars/Hamiltonian.html#ComplexScalingTheta"))
 insDoc(aux1, gLnk("R", "ConductivityFromForces", "vars/Utilities.html#ConductivityFromForces"))
 insDoc(aux1, gLnk("R", "ConductivitySpectrumTimeStepFactor", "vars/Utilities.html#ConductivitySpectrumTimeStepFactor"))
 insDoc(aux1, gLnk("R", "ConvAbsDens", "vars/SCF.html#ConvAbsDens"))
@@ -112,15 +108,19 @@ insDoc(aux1, gLnk("R", "CurvModineJrange", "vars/Mesh.html#CurvModineJrange"))
 insDoc(aux1, gLnk("R", "CurvModineXBar", "vars/Mesh.html#CurvModineXBar"))
 aux1 = insFld(aux0, gFld("D", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Debug", "vars/Execution.html#Debug"))
+insDoc(aux1, gLnk("R", "DebugTrapSignals", "vars/Execution.html#DebugTrapSignals"))
 insDoc(aux1, gLnk("R", "DegeneracyThreshold", "vars/States.html#DegeneracyThreshold"))
 insDoc(aux1, gLnk("R", "DeltaEFMM", "vars/Hamiltonian.html#DeltaEFMM"))
 insDoc(aux1, gLnk("R", "DensitytoCalc", "vars/States.html#DensitytoCalc"))
 insDoc(aux1, gLnk("R", "DerivativesOrder", "vars/Mesh.html#DerivativesOrder"))
 insDoc(aux1, gLnk("R", "DerivativesStencil", "vars/Mesh.html#DerivativesStencil"))
 insDoc(aux1, gLnk("R", "DescribeParticlesModelmb", "vars/States.html#DescribeParticlesModelmb"))
+insDoc(aux1, gLnk("R", "DFTUBasisFromStates", "vars/Hamiltonian.html#DFTUBasisFromStates"))
+insDoc(aux1, gLnk("R", "DFTUBasisStates", "vars/Hamiltonian.html#DFTUBasisStates"))
+insDoc(aux1, gLnk("R", "DFTUDoubleCounting", "vars/Hamiltonian.html#DFTUDoubleCounting"))
 insDoc(aux1, gLnk("R", "DFTULevel", "vars/Hamiltonian.html#DFTULevel"))
 insDoc(aux1, gLnk("R", "Dimensions", "vars/System.html#Dimensions"))
-insDoc(aux1, gLnk("R", "DisableOpenCL", "vars/Execution.html#DisableOpenCL"))
+insDoc(aux1, gLnk("R", "DisableAccel", "vars/Execution.html#DisableAccel"))
 insDoc(aux1, gLnk("R", "Displacement", "vars/Linear_Response.html#Displacement"))
 insDoc(aux1, gLnk("R", "DOSComputePDOS", "vars/Output.html#DOSComputePDOS"))
 insDoc(aux1, gLnk("R", "DOSEnergyMax", "vars/Output.html#DOSEnergyMax"))
@@ -132,14 +132,9 @@ insDoc(aux1, gLnk("R", "DoubleGrid", "vars/Mesh.html#DoubleGrid"))
 insDoc(aux1, gLnk("R", "DoubleGridOrder", "vars/Mesh.html#DoubleGridOrder"))
 aux1 = insFld(aux0, gFld("E", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Eigensolver", "vars/SCF.html#Eigensolver"))
-insDoc(aux1, gLnk("R", "EigensolverArnoldiVectors", "vars/SCF.html#EigensolverArnoldiVectors"))
-insDoc(aux1, gLnk("R", "EigensolverArpackInitialResid", "vars/SCF.html#EigensolverArpackInitialResid"))
-insDoc(aux1, gLnk("R", "EigensolverArpackSort", "vars/SCF.html#EigensolverArpackSort"))
 insDoc(aux1, gLnk("R", "EigensolverImaginaryTime", "vars/SCF.html#EigensolverImaginaryTime"))
 insDoc(aux1, gLnk("R", "EigensolverMaxIter", "vars/SCF.html#EigensolverMaxIter"))
 insDoc(aux1, gLnk("R", "EigensolverMinimizationIter", "vars/SCF.html#EigensolverMinimizationIter"))
-insDoc(aux1, gLnk("R", "EigensolverParpack", "vars/SCF.html#EigensolverParpack"))
-insDoc(aux1, gLnk("R", "EigensolverSaveMemory", "vars/SCF.html#EigensolverSaveMemory"))
 insDoc(aux1, gLnk("R", "EigensolverSkipKpoints", "vars/SCF.html#EigensolverSkipKpoints"))
 insDoc(aux1, gLnk("R", "EigensolverTolerance", "vars/SCF.html#EigensolverTolerance"))
 insDoc(aux1, gLnk("R", "ELFWithCurrentTerm", "vars/Output.html#ELFWithCurrentTerm"))
@@ -152,6 +147,7 @@ insDoc(aux1, gLnk("R", "EMForceNoKdotP", "vars/Linear_Response.html#EMForceNoKdo
 insDoc(aux1, gLnk("R", "EMFreqs", "vars/Linear_Response.html#EMFreqs"))
 insDoc(aux1, gLnk("R", "EMFreqsSort", "vars/Linear_Response.html#EMFreqsSort"))
 insDoc(aux1, gLnk("R", "EMHyperpol", "vars/Linear_Response.html#EMHyperpol"))
+insDoc(aux1, gLnk("R", "EMKPointOutput", "vars/Linear_Response.html#EMKPointOutput"))
 insDoc(aux1, gLnk("R", "EMMagnetoopticsNoHVar", "vars/Linear_Response.html#EMMagnetoopticsNoHVar"))
 insDoc(aux1, gLnk("R", "EMOccupiedResponse", "vars/Linear_Response.html#EMOccupiedResponse"))
 insDoc(aux1, gLnk("R", "EMPerturbationType", "vars/Linear_Response.html#EMPerturbationType"))
@@ -166,8 +162,6 @@ insDoc(aux1, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#Experimental
 insDoc(aux1, gLnk("R", "ExtraStates", "vars/States.html#ExtraStates"))
 insDoc(aux1, gLnk("R", "ExtraStatesToConverge", "vars/States.html#ExtraStatesToConverge"))
 aux1 = insFld(aux0, gFld("F", "javascript:parent.op()"))
-insDoc(aux1, gLnk("R", "FeastContour", "vars/SCF.html#FeastContour"))
-insDoc(aux1, gLnk("R", "FeastMaxIter", "vars/SCF.html#FeastMaxIter"))
 insDoc(aux1, gLnk("R", "FFTLibrary", "vars/Mesh.html#FFTLibrary"))
 insDoc(aux1, gLnk("R", "FFTOptimize", "vars/Mesh.html#FFTOptimize"))
 insDoc(aux1, gLnk("R", "FFTPreparePlan", "vars/Mesh.html#FFTPreparePlan"))
@@ -176,8 +170,6 @@ insDoc(aux1, gLnk("R", "FlushMessages", "vars/Execution.html#FlushMessages"))
 insDoc(aux1, gLnk("R", "ForceComplex", "vars/Execution.html#ForceComplex"))
 insDoc(aux1, gLnk("R", "ForceTotalEnforce", "vars/Hamiltonian.html#ForceTotalEnforce"))
 insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
-insDoc(aux1, gLnk("R", "FrozenDir", "vars/Output.html#FrozenDir"))
-insDoc(aux1, gLnk("R", "FrozenStates", "vars/Output.html#FrozenStates"))
 aux1 = insFld(aux0, gFld("G", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "GaugeFieldDelay", "vars/Hamiltonian.html#GaugeFieldDelay"))
 insDoc(aux1, gLnk("R", "GaugeFieldDynamics", "vars/Hamiltonian.html#GaugeFieldDynamics"))
@@ -213,7 +205,6 @@ insDoc(aux1, gLnk("R", "InvertKSStellaAlpha", "vars/Calculation_Modes.html#Inver
 insDoc(aux1, gLnk("R", "InvertKSStellaBeta", "vars/Calculation_Modes.html#InvertKSStellaBeta"))
 insDoc(aux1, gLnk("R", "InvertKSTargetDensity", "vars/Calculation_Modes.html#InvertKSTargetDensity"))
 insDoc(aux1, gLnk("R", "InvertKSVerbosity", "vars/Calculation_Modes.html#InvertKSVerbosity"))
-insDoc(aux1, gLnk("R", "IonicInteraction", "vars/System.html#IonicInteraction"))
 insDoc(aux1, gLnk("R", "IonsConstantVelocity", "vars/Time-Dependent.html#IonsConstantVelocity"))
 insDoc(aux1, gLnk("R", "IonsTimeDependentDisplacements", "vars/Time-Dependent.html#IonsTimeDependentDisplacements"))
 aux1 = insFld(aux0, gFld("K", "javascript:parent.op()"))
@@ -303,6 +294,7 @@ insDoc(aux1, gLnk("R", "MixNumberSteps", "vars/SCF.html#MixNumberSteps"))
 insDoc(aux1, gLnk("R", "MomentumTransfer", "vars/Output.html#MomentumTransfer"))
 insDoc(aux1, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
 insDoc(aux1, gLnk("R", "MPIDebugHook", "vars/Execution.html#MPIDebugHook"))
+insDoc(aux1, gLnk("R", "MultigridDerivativesOrder", "vars/Mesh.html#MultigridDerivativesOrder"))
 insDoc(aux1, gLnk("R", "MultigridLevels", "vars/Mesh.html#MultigridLevels"))
 insDoc(aux1, gLnk("R", "MultiResolutionArea", "vars/Mesh.html#MultiResolutionArea"))
 insDoc(aux1, gLnk("R", "MultiResolutionInterpolationOrder", "vars/Mesh.html#MultiResolutionInterpolationOrder"))
@@ -365,7 +357,6 @@ insDoc(aux1, gLnk("R", "OnlyUserDefinedInitialStates", "vars/States.html#OnlyUse
 insDoc(aux1, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark"))
 insDoc(aux1, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
 insDoc(aux1, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
-insDoc(aux1, gLnk("R", "OpenSCADIsovalue", "vars/Output.html#OpenSCADIsovalue"))
 insDoc(aux1, gLnk("R", "OperateComplex", "vars/Execution.html#OperateComplex"))
 insDoc(aux1, gLnk("R", "OperateComplexSingle", "vars/Execution.html#OperateComplexSingle"))
 insDoc(aux1, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
@@ -375,7 +366,6 @@ insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
 insDoc(aux1, gLnk("R", "Output_KPT", "vars/Output.html#Output_KPT"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
 insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
-insDoc(aux1, gLnk("R", "OutputGradientPotential", "vars/Output.html#OutputGradientPotential"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
 insDoc(aux1, gLnk("R", "OutputLDA_U", "vars/Output.html#OutputLDA_U"))
@@ -386,6 +376,7 @@ aux1 = insFld(aux0, gFld("P", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "ParallelizationNumberSlaves", "vars/Execution.html#ParallelizationNumberSlaves"))
 insDoc(aux1, gLnk("R", "ParallelizationOfDerivatives", "vars/Execution.html#ParallelizationOfDerivatives"))
 insDoc(aux1, gLnk("R", "ParallelizationPoissonAllNodes", "vars/Execution.html#ParallelizationPoissonAllNodes"))
+insDoc(aux1, gLnk("R", "ParallelXC", "vars/Execution.html#ParallelXC"))
 insDoc(aux1, gLnk("R", "ParDomains", "vars/Execution.html#ParDomains"))
 insDoc(aux1, gLnk("R", "ParKPoints", "vars/Execution.html#ParKPoints"))
 insDoc(aux1, gLnk("R", "ParOther", "vars/Execution.html#ParOther"))
@@ -481,6 +472,9 @@ insDoc(aux1, gLnk("R", "PoissonSolverNodes", "vars/Hamiltonian.html#PoissonSolve
 insDoc(aux1, gLnk("R", "PoissonSolverThreshold", "vars/Hamiltonian.html#PoissonSolverThreshold"))
 insDoc(aux1, gLnk("R", "Preconditioner", "vars/SCF.html#Preconditioner"))
 insDoc(aux1, gLnk("R", "PreconditionerFilterFactor", "vars/SCF.html#PreconditionerFilterFactor"))
+insDoc(aux1, gLnk("R", "PreconditionerIterationsMiddle", "vars/SCF.html#PreconditionerIterationsMiddle"))
+insDoc(aux1, gLnk("R", "PreconditionerIterationsPost", "vars/SCF.html#PreconditionerIterationsPost"))
+insDoc(aux1, gLnk("R", "PreconditionerIterationsPre", "vars/SCF.html#PreconditionerIterationsPre"))
 insDoc(aux1, gLnk("R", "Preorthogonalization", "vars/Linear_Response.html#Preorthogonalization"))
 insDoc(aux1, gLnk("R", "ProfilingAllNodes", "vars/Execution.html#ProfilingAllNodes"))
 insDoc(aux1, gLnk("R", "ProfilingMode", "vars/Execution.html#ProfilingMode"))
@@ -491,8 +485,11 @@ insDoc(aux1, gLnk("R", "PropagationSpectrumEnergyStep", "vars/Utilities.html#Pro
 insDoc(aux1, gLnk("R", "PropagationSpectrumMaxEnergy", "vars/Utilities.html#PropagationSpectrumMaxEnergy"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumSigmaDiagonalization", "vars/Utilities.html#PropagationSpectrumSigmaDiagonalization"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#PropagationSpectrumStartTime"))
+insDoc(aux1, gLnk("R", "PropagationSpectrumSymmetrizeSigma", "vars/Utilities.html#PropagationSpectrumSymmetrizeSigma"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumTransform", "vars/Utilities.html#PropagationSpectrumTransform"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#PropagationSpectrumType"))
+insDoc(aux1, gLnk("R", "PseudopotentialAutomaticParameters", "vars/System.html#PseudopotentialAutomaticParameters"))
+insDoc(aux1, gLnk("R", "PseudopotentialEnergyTolerance", "vars/System.html#PseudopotentialEnergyTolerance"))
 insDoc(aux1, gLnk("R", "PseudopotentialSet", "vars/System.html#PseudopotentialSet"))
 aux1 = insFld(aux0, gFld("R", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Radius", "vars/Mesh.html#Radius"))
@@ -550,6 +547,7 @@ insDoc(aux1, gLnk("R", "SpinComponents", "vars/States.html#SpinComponents"))
 insDoc(aux1, gLnk("R", "Splines", "vars/Execution.html#Splines"))
 insDoc(aux1, gLnk("R", "StatesBlockSize", "vars/Execution.html#StatesBlockSize"))
 insDoc(aux1, gLnk("R", "StatesCLDeviceMemory", "vars/Execution.html#StatesCLDeviceMemory"))
+insDoc(aux1, gLnk("R", "StatesMirror", "vars/Execution.html#StatesMirror"))
 insDoc(aux1, gLnk("R", "StatesOrthogonalization", "vars/SCF.html#StatesOrthogonalization"))
 insDoc(aux1, gLnk("R", "StatesPack", "vars/Execution.html#StatesPack"))
 insDoc(aux1, gLnk("R", "StatesRandomization", "vars/States.html#StatesRandomization"))
@@ -559,8 +557,6 @@ insDoc(aux1, gLnk("R", "StaticMagneticField2DGauge", "vars/Hamiltonian.html#Stat
 insDoc(aux1, gLnk("R", "stderr", "vars/Execution.html#stderr"))
 insDoc(aux1, gLnk("R", "stdout", "vars/Execution.html#stdout"))
 insDoc(aux1, gLnk("R", "SubspaceDiagonalization", "vars/SCF.html#SubspaceDiagonalization"))
-insDoc(aux1, gLnk("R", "SubSystemCoordinates", "vars/System.html#SubSystemCoordinates"))
-insDoc(aux1, gLnk("R", "SubSystems", "vars/System.html#SubSystems"))
 insDoc(aux1, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompute"))
 insDoc(aux1, gLnk("R", "SymmetrizeDensity", "vars/States.html#SymmetrizeDensity"))
 insDoc(aux1, gLnk("R", "SymmetrizeDynamicalMatrix", "vars/Linear_Response.html#SymmetrizeDynamicalMatrix"))
@@ -606,6 +602,7 @@ insDoc(aux1, gLnk("R", "TDScissor", "vars/Time-Dependent.html#TDScissor"))
 insDoc(aux1, gLnk("R", "TDStepsWithSelfConsistency", "vars/Time-Dependent.html#TDStepsWithSelfConsistency"))
 insDoc(aux1, gLnk("R", "TDTimeStep", "vars/Time-Dependent.html#TDTimeStep"))
 insDoc(aux1, gLnk("R", "TemperatureFunction", "vars/Time-Dependent.html#TemperatureFunction"))
+insDoc(aux1, gLnk("R", "TestHamiltonianApply", "vars/Utilities.html#TestHamiltonianApply"))
 insDoc(aux1, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
 insDoc(aux1, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
 insDoc(aux1, gLnk("R", "TestMode", "vars/Utilities.html#TestMode"))
@@ -615,11 +612,9 @@ insDoc(aux1, gLnk("R", "TheoryLevel", "vars/Hamiltonian.html#TheoryLevel"))
 insDoc(aux1, gLnk("R", "Thermostat", "vars/Time-Dependent.html#Thermostat"))
 insDoc(aux1, gLnk("R", "ThermostatMass", "vars/Time-Dependent.html#ThermostatMass"))
 insDoc(aux1, gLnk("R", "TimeZero", "vars/Hamiltonian.html#TimeZero"))
-insDoc(aux1, gLnk("R", "TnaddFactor", "vars/Hamiltonian.html#TnaddFactor"))
-insDoc(aux1, gLnk("R", "TnaddFunctional", "vars/Hamiltonian.html#TnaddFunctional"))
-insDoc(aux1, gLnk("R", "TnaddPolarized", "vars/Hamiltonian.html#TnaddPolarized"))
 insDoc(aux1, gLnk("R", "TotalStates", "vars/States.html#TotalStates"))
 insDoc(aux1, gLnk("R", "TransformStates", "vars/States.html#TransformStates"))
+insDoc(aux1, gLnk("R", "TransientAbsorptionReference", "vars/Utilities.html#TransientAbsorptionReference"))
 aux1 = insFld(aux0, gFld("U", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Units", "vars/Execution.html#Units"))
 insDoc(aux1, gLnk("R", "UnitsOutput", "vars/Execution.html#UnitsOutput"))
@@ -629,6 +624,9 @@ insDoc(aux1, gLnk("R", "UseAllAtomicOrbitals", "vars/Hamiltonian.html#UseAllAtom
 insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
 insDoc(aux1, gLnk("R", "UserDefinedStates", "vars/States.html#UserDefinedStates"))
 aux1 = insFld(aux0, gFld("V", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "VDW_TS_cutoff", "vars/Hamiltonian.html#VDW_TS_cutoff"))
+insDoc(aux1, gLnk("R", "VDW_TS_damping", "vars/Hamiltonian.html#VDW_TS_damping"))
+insDoc(aux1, gLnk("R", "VDW_TS_sr", "vars/Hamiltonian.html#VDW_TS_sr"))
 insDoc(aux1, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
 insDoc(aux1, gLnk("R", "VDWD3Functional", "vars/Hamiltonian.html#VDWD3Functional"))
 insDoc(aux1, gLnk("R", "vdWNPoints", "vars/Linear_Response.html#vdWNPoints"))
@@ -651,7 +649,6 @@ insDoc(aux1, gLnk("R", "XCDensityCorrectionOptimize", "vars/Hamiltonian.html#XCD
 insDoc(aux1, gLnk("R", "XCFunctional", "vars/Hamiltonian.html#XCFunctional"))
 insDoc(aux1, gLnk("R", "XCKernel", "vars/Hamiltonian.html#XCKernel"))
 insDoc(aux1, gLnk("R", "XCKernelLRCAlpha", "vars/Hamiltonian.html#XCKernelLRCAlpha"))
-insDoc(aux1, gLnk("R", "XCParallel", "vars/Execution.html#XCParallel"))
 insDoc(aux1, gLnk("R", "XCUseGaugeIndependentKED", "vars/Hamiltonian.html#XCUseGaugeIndependentKED"))
 insDoc(aux1, gLnk("R", "Xlength", "vars/Mesh.html#Xlength"))
 insDoc(aux1, gLnk("R", "XSFCoordinates", "vars/System.html#XSFCoordinates"))
