@@ -82,8 +82,14 @@ insDoc(aux2, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccS
 aux1 = insFld(aux0, gFld("Execution", "vars/Execution.html#Execution"))
 insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
 insDoc(aux1, gLnk("R", "Splines", "vars/Execution.html#Splines"))
+aux2 = insFld(aux1, gFld("Accel", "vars/Execution.html#Execution::Accel"))
+insDoc(aux2, gLnk("R", "DisableAccel", "vars/Execution.html#DisableAccel"))
+insDoc(aux2, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark"))
+insDoc(aux2, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
+insDoc(aux2, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
 aux2 = insFld(aux1, gFld("Debug", "vars/Execution.html#Execution::Debug"))
 insDoc(aux2, gLnk("R", "Debug", "vars/Execution.html#Debug"))
+insDoc(aux2, gLnk("R", "DebugTrapSignals", "vars/Execution.html#DebugTrapSignals"))
 insDoc(aux2, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#ExperimentalFeatures"))
 insDoc(aux2, gLnk("R", "ForceComplex", "vars/Execution.html#ForceComplex"))
 insDoc(aux2, gLnk("R", "MPIDebugHook", "vars/Execution.html#MPIDebugHook"))
@@ -96,11 +102,6 @@ insDoc(aux2, gLnk("R", "RestartWriteInterval", "vars/Execution.html#RestartWrite
 insDoc(aux2, gLnk("R", "WorkDir", "vars/Execution.html#WorkDir"))
 insDoc(aux2, gLnk("R", "stderr", "vars/Execution.html#stderr"))
 insDoc(aux2, gLnk("R", "stdout", "vars/Execution.html#stdout"))
-aux2 = insFld(aux1, gFld("OpenCL", "vars/Execution.html#Execution::OpenCL"))
-insDoc(aux2, gLnk("R", "DisableOpenCL", "vars/Execution.html#DisableOpenCL"))
-insDoc(aux2, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark"))
-insDoc(aux2, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
-insDoc(aux2, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
 aux2 = insFld(aux1, gFld("Optimization", "vars/Execution.html#Execution::Optimization"))
 insDoc(aux2, gLnk("R", "HamiltonianApplyPacked", "vars/Execution.html#HamiltonianApplyPacked"))
 insDoc(aux2, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
@@ -116,6 +117,7 @@ insDoc(aux2, gLnk("R", "ProfilingAllNodes", "vars/Execution.html#ProfilingAllNod
 insDoc(aux2, gLnk("R", "ProfilingMode", "vars/Execution.html#ProfilingMode"))
 insDoc(aux2, gLnk("R", "StatesBlockSize", "vars/Execution.html#StatesBlockSize"))
 insDoc(aux2, gLnk("R", "StatesCLDeviceMemory", "vars/Execution.html#StatesCLDeviceMemory"))
+insDoc(aux2, gLnk("R", "StatesMirror", "vars/Execution.html#StatesMirror"))
 insDoc(aux2, gLnk("R", "StatesPack", "vars/Execution.html#StatesPack"))
 aux2 = insFld(aux1, gFld("Parallelization", "vars/Execution.html#Execution::Parallelization"))
 insDoc(aux2, gLnk("R", "MeshPartition", "vars/Execution.html#MeshPartition"))
@@ -127,12 +129,12 @@ insDoc(aux2, gLnk("R", "ParDomains", "vars/Execution.html#ParDomains"))
 insDoc(aux2, gLnk("R", "ParKPoints", "vars/Execution.html#ParKPoints"))
 insDoc(aux2, gLnk("R", "ParOther", "vars/Execution.html#ParOther"))
 insDoc(aux2, gLnk("R", "ParStates", "vars/Execution.html#ParStates"))
+insDoc(aux2, gLnk("R", "ParallelXC", "vars/Execution.html#ParallelXC"))
 insDoc(aux2, gLnk("R", "ParallelizationNumberSlaves", "vars/Execution.html#ParallelizationNumberSlaves"))
 insDoc(aux2, gLnk("R", "ParallelizationOfDerivatives", "vars/Execution.html#ParallelizationOfDerivatives"))
 insDoc(aux2, gLnk("R", "ParallelizationPoissonAllNodes", "vars/Execution.html#ParallelizationPoissonAllNodes"))
 insDoc(aux2, gLnk("R", "PartitionPrint", "vars/Execution.html#PartitionPrint"))
 insDoc(aux2, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKCompatible"))
-insDoc(aux2, gLnk("R", "XCParallel", "vars/Execution.html#XCParallel"))
 aux2 = insFld(aux1, gFld("Symmetries", "vars/Execution.html#Execution::Symmetries"))
 insDoc(aux2, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompute"))
 aux2 = insFld(aux1, gFld("Units", "vars/Execution.html#Execution::Units"))
@@ -165,22 +167,17 @@ insDoc(aux1, gLnk("R", "StaticMagneticField", "vars/Hamiltonian.html#StaticMagne
 insDoc(aux1, gLnk("R", "StaticMagneticField2DGauge", "vars/Hamiltonian.html#StaticMagneticField2DGauge"))
 insDoc(aux1, gLnk("R", "TheoryLevel", "vars/Hamiltonian.html#TheoryLevel"))
 insDoc(aux1, gLnk("R", "TimeZero", "vars/Hamiltonian.html#TimeZero"))
-aux2 = insFld(aux1, gFld("ComplexScaling", "vars/Hamiltonian.html#Hamiltonian::ComplexScaling"))
-insDoc(aux2, gLnk("R", "ComplexScaling", "vars/Hamiltonian.html#ComplexScaling"))
-insDoc(aux2, gLnk("R", "ComplexScalingAlpha", "vars/Hamiltonian.html#ComplexScalingAlpha"))
-insDoc(aux2, gLnk("R", "ComplexScalingAlphaLeft", "vars/Hamiltonian.html#ComplexScalingAlphaLeft"))
-insDoc(aux2, gLnk("R", "ComplexScalingLocalizationRadius", "vars/Hamiltonian.html#ComplexScalingLocalizationRadius"))
-insDoc(aux2, gLnk("R", "ComplexScalingLocalizationThreshold", "vars/Hamiltonian.html#ComplexScalingLocalizationThreshold"))
-insDoc(aux2, gLnk("R", "ComplexScalingLocalizedStates", "vars/Hamiltonian.html#ComplexScalingLocalizedStates"))
-insDoc(aux2, gLnk("R", "ComplexScalingPenalizationFactor", "vars/Hamiltonian.html#ComplexScalingPenalizationFactor"))
-insDoc(aux2, gLnk("R", "ComplexScalingRotateSpectrum", "vars/Hamiltonian.html#ComplexScalingRotateSpectrum"))
-insDoc(aux2, gLnk("R", "ComplexScalingTheta", "vars/Hamiltonian.html#ComplexScalingTheta"))
 aux2 = insFld(aux1, gFld("DFT+U", "vars/Hamiltonian.html#Hamiltonian::DFT+U"))
+insDoc(aux2, gLnk("R", "ACBN0RotationallyInvariant", "vars/Hamiltonian.html#ACBN0RotationallyInvariant"))
+insDoc(aux2, gLnk("R", "ACBN0Screening", "vars/Hamiltonian.html#ACBN0Screening"))
 insDoc(aux2, gLnk("R", "AOLoewdin", "vars/Hamiltonian.html#AOLoewdin"))
 insDoc(aux2, gLnk("R", "AONormalize", "vars/Hamiltonian.html#AONormalize"))
 insDoc(aux2, gLnk("R", "AOSubmeshForPeriodic", "vars/Hamiltonian.html#AOSubmeshForPeriodic"))
 insDoc(aux2, gLnk("R", "AOThreshold", "vars/Hamiltonian.html#AOThreshold"))
 insDoc(aux2, gLnk("R", "AOTruncation", "vars/Hamiltonian.html#AOTruncation"))
+insDoc(aux2, gLnk("R", "DFTUBasisFromStates", "vars/Hamiltonian.html#DFTUBasisFromStates"))
+insDoc(aux2, gLnk("R", "DFTUBasisStates", "vars/Hamiltonian.html#DFTUBasisStates"))
+insDoc(aux2, gLnk("R", "DFTUDoubleCounting", "vars/Hamiltonian.html#DFTUDoubleCounting"))
 insDoc(aux2, gLnk("R", "SkipSOrbitals", "vars/Hamiltonian.html#SkipSOrbitals"))
 insDoc(aux2, gLnk("R", "UseAllAtomicOrbitals", "vars/Hamiltonian.html#UseAllAtomicOrbitals"))
 aux2 = insFld(aux1, gFld("PCM", "vars/Hamiltonian.html#Hamiltonian::PCM"))
@@ -231,10 +228,6 @@ insDoc(aux3, gLnk("R", "PoissonSolverMGPresmoothingSteps", "vars/Hamiltonian.htm
 insDoc(aux3, gLnk("R", "PoissonSolverMGRelaxationFactor", "vars/Hamiltonian.html#PoissonSolverMGRelaxationFactor"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGRelaxationMethod", "vars/Hamiltonian.html#PoissonSolverMGRelaxationMethod"))
 insDoc(aux3, gLnk("R", "PoissonSolverMGRestrictionMethod", "vars/Hamiltonian.html#PoissonSolverMGRestrictionMethod"))
-aux2 = insFld(aux1, gFld("Subsystems", "vars/Hamiltonian.html#Hamiltonian::Subsystems"))
-insDoc(aux2, gLnk("R", "TnaddFactor", "vars/Hamiltonian.html#TnaddFactor"))
-insDoc(aux2, gLnk("R", "TnaddFunctional", "vars/Hamiltonian.html#TnaddFunctional"))
-insDoc(aux2, gLnk("R", "TnaddPolarized", "vars/Hamiltonian.html#TnaddPolarized"))
 aux2 = insFld(aux1, gFld("XC", "vars/Hamiltonian.html#Hamiltonian::XC"))
 insDoc(aux2, gLnk("R", "DFTULevel", "vars/Hamiltonian.html#DFTULevel"))
 insDoc(aux2, gLnk("R", "Interaction1D", "vars/Hamiltonian.html#Interaction1D"))
@@ -247,6 +240,9 @@ insDoc(aux2, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
 insDoc(aux2, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
 insDoc(aux2, gLnk("R", "VDWD3Functional", "vars/Hamiltonian.html#VDWD3Functional"))
 insDoc(aux2, gLnk("R", "VDWSelfConsistent", "vars/Hamiltonian.html#VDWSelfConsistent"))
+insDoc(aux2, gLnk("R", "VDW_TS_cutoff", "vars/Hamiltonian.html#VDW_TS_cutoff"))
+insDoc(aux2, gLnk("R", "VDW_TS_damping", "vars/Hamiltonian.html#VDW_TS_damping"))
+insDoc(aux2, gLnk("R", "VDW_TS_sr", "vars/Hamiltonian.html#VDW_TS_sr"))
 insDoc(aux2, gLnk("R", "XCFunctional", "vars/Hamiltonian.html#XCFunctional"))
 insDoc(aux2, gLnk("R", "XCKernel", "vars/Hamiltonian.html#XCKernel"))
 insDoc(aux2, gLnk("R", "XCKernelLRCAlpha", "vars/Hamiltonian.html#XCKernelLRCAlpha"))
@@ -295,6 +291,7 @@ insDoc(aux2, gLnk("R", "EMForceNoKdotP", "vars/Linear_Response.html#EMForceNoKdo
 insDoc(aux2, gLnk("R", "EMFreqs", "vars/Linear_Response.html#EMFreqs"))
 insDoc(aux2, gLnk("R", "EMFreqsSort", "vars/Linear_Response.html#EMFreqsSort"))
 insDoc(aux2, gLnk("R", "EMHyperpol", "vars/Linear_Response.html#EMHyperpol"))
+insDoc(aux2, gLnk("R", "EMKPointOutput", "vars/Linear_Response.html#EMKPointOutput"))
 insDoc(aux2, gLnk("R", "EMMagnetoopticsNoHVar", "vars/Linear_Response.html#EMMagnetoopticsNoHVar"))
 insDoc(aux2, gLnk("R", "EMOccupiedResponse", "vars/Linear_Response.html#EMOccupiedResponse"))
 insDoc(aux2, gLnk("R", "EMPerturbationType", "vars/Linear_Response.html#EMPerturbationType"))
@@ -366,6 +363,7 @@ insDoc(aux3, gLnk("R", "CurvModineXBar", "vars/Mesh.html#CurvModineXBar"))
 aux2 = insFld(aux1, gFld("Derivatives", "vars/Mesh.html#Mesh::Derivatives"))
 insDoc(aux2, gLnk("R", "DerivativesOrder", "vars/Mesh.html#DerivativesOrder"))
 insDoc(aux2, gLnk("R", "DerivativesStencil", "vars/Mesh.html#DerivativesStencil"))
+insDoc(aux2, gLnk("R", "MultigridDerivativesOrder", "vars/Mesh.html#MultigridDerivativesOrder"))
 aux2 = insFld(aux1, gFld("FFTs", "vars/Mesh.html#Mesh::FFTs"))
 insDoc(aux2, gLnk("R", "DoubleFFTParameter", "vars/Mesh.html#DoubleFFTParameter"))
 insDoc(aux2, gLnk("R", "FFTLibrary", "vars/Mesh.html#FFTLibrary"))
@@ -405,11 +403,9 @@ insDoc(aux1, gLnk("R", "DOSGamma", "vars/Output.html#DOSGamma"))
 insDoc(aux1, gLnk("R", "ELFWithCurrentTerm", "vars/Output.html#ELFWithCurrentTerm"))
 insDoc(aux1, gLnk("R", "LocalMagneticMomentsSphereRadius", "vars/Output.html#LocalMagneticMomentsSphereRadius"))
 insDoc(aux1, gLnk("R", "MomentumTransfer", "vars/Output.html#MomentumTransfer"))
-insDoc(aux1, gLnk("R", "OpenSCADIsovalue", "vars/Output.html#OpenSCADIsovalue"))
 insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
 insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
-insDoc(aux1, gLnk("R", "OutputGradientPotential", "vars/Output.html#OutputGradientPotential"))
 insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
 insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
 insDoc(aux1, gLnk("R", "OutputLDA_U", "vars/Output.html#OutputLDA_U"))
@@ -429,9 +425,6 @@ insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_diag_nmin", "vars/Output.html#BerkeleyGW_
 insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmax", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmax"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmin", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmin"))
 insDoc(aux2, gLnk("R", "BerkeleyGW_WFN_filename", "vars/Output.html#BerkeleyGW_WFN_filename"))
-aux2 = insFld(aux1, gFld("Subsystems", "vars/Output.html#Output::Subsystems"))
-insDoc(aux2, gLnk("R", "FrozenDir", "vars/Output.html#FrozenDir"))
-insDoc(aux2, gLnk("R", "FrozenStates", "vars/Output.html#FrozenStates"))
 aux1 = insFld(aux0, gFld("SCF", "vars/SCF.html#SCF"))
 insDoc(aux1, gLnk("R", "CalcEigenvalues", "vars/SCF.html#CalcEigenvalues"))
 insDoc(aux1, gLnk("R", "SCFCalculateDipole", "vars/SCF.html#SCFCalculateDipole"))
@@ -450,26 +443,22 @@ insDoc(aux2, gLnk("R", "ConvRelEv", "vars/SCF.html#ConvRelEv"))
 insDoc(aux2, gLnk("R", "MaximumIter", "vars/SCF.html#MaximumIter"))
 insDoc(aux2, gLnk("R", "MaximumIterBerry", "vars/SCF.html#MaximumIterBerry"))
 aux2 = insFld(aux1, gFld("Eigensolver", "vars/SCF.html#SCF::Eigensolver"))
+insDoc(aux2, gLnk("R", "CGAdditionalTerms", "vars/SCF.html#CGAdditionalTerms"))
+insDoc(aux2, gLnk("R", "CGDirection", "vars/SCF.html#CGDirection"))
+insDoc(aux2, gLnk("R", "CGOrthogonalizeAll", "vars/SCF.html#CGOrthogonalizeAll"))
 insDoc(aux2, gLnk("R", "Eigensolver", "vars/SCF.html#Eigensolver"))
-insDoc(aux2, gLnk("R", "EigensolverArnoldiVectors", "vars/SCF.html#EigensolverArnoldiVectors"))
 insDoc(aux2, gLnk("R", "EigensolverImaginaryTime", "vars/SCF.html#EigensolverImaginaryTime"))
 insDoc(aux2, gLnk("R", "EigensolverMaxIter", "vars/SCF.html#EigensolverMaxIter"))
 insDoc(aux2, gLnk("R", "EigensolverMinimizationIter", "vars/SCF.html#EigensolverMinimizationIter"))
-insDoc(aux2, gLnk("R", "EigensolverSaveMemory", "vars/SCF.html#EigensolverSaveMemory"))
 insDoc(aux2, gLnk("R", "EigensolverSkipKpoints", "vars/SCF.html#EigensolverSkipKpoints"))
 insDoc(aux2, gLnk("R", "EigensolverTolerance", "vars/SCF.html#EigensolverTolerance"))
 insDoc(aux2, gLnk("R", "Preconditioner", "vars/SCF.html#Preconditioner"))
 insDoc(aux2, gLnk("R", "PreconditionerFilterFactor", "vars/SCF.html#PreconditionerFilterFactor"))
+insDoc(aux2, gLnk("R", "PreconditionerIterationsMiddle", "vars/SCF.html#PreconditionerIterationsMiddle"))
+insDoc(aux2, gLnk("R", "PreconditionerIterationsPost", "vars/SCF.html#PreconditionerIterationsPost"))
+insDoc(aux2, gLnk("R", "PreconditionerIterationsPre", "vars/SCF.html#PreconditionerIterationsPre"))
 insDoc(aux2, gLnk("R", "StatesOrthogonalization", "vars/SCF.html#StatesOrthogonalization"))
 insDoc(aux2, gLnk("R", "SubspaceDiagonalization", "vars/SCF.html#SubspaceDiagonalization"))
-aux3 = insFld(aux2, gFld("ARPACK", "vars/SCF.html#SCF::Eigensolver::ARPACK"))
-insDoc(aux3, gLnk("R", "ArpackInitialTolerance", "vars/SCF.html#ArpackInitialTolerance"))
-insDoc(aux3, gLnk("R", "EigensolverArpackInitialResid", "vars/SCF.html#EigensolverArpackInitialResid"))
-insDoc(aux3, gLnk("R", "EigensolverArpackSort", "vars/SCF.html#EigensolverArpackSort"))
-insDoc(aux3, gLnk("R", "EigensolverParpack", "vars/SCF.html#EigensolverParpack"))
-aux3 = insFld(aux2, gFld("FEAST", "vars/SCF.html#SCF::Eigensolver::FEAST"))
-insDoc(aux3, gLnk("R", "FeastContour", "vars/SCF.html#FeastContour"))
-insDoc(aux3, gLnk("R", "FeastMaxIter", "vars/SCF.html#FeastMaxIter"))
 aux2 = insFld(aux1, gFld("LCAO", "vars/SCF.html#SCF::LCAO"))
 insDoc(aux2, gLnk("R", "AtomsMagnetDirection", "vars/SCF.html#AtomsMagnetDirection"))
 insDoc(aux2, gLnk("R", "GuessMagnetDensity", "vars/SCF.html#GuessMagnetDensity"))
@@ -531,14 +520,12 @@ insDoc(aux2, gLnk("R", "XSFCoordinates", "vars/System.html#XSFCoordinates"))
 insDoc(aux2, gLnk("R", "XSFCoordinatesAnimStep", "vars/System.html#XSFCoordinatesAnimStep"))
 insDoc(aux2, gLnk("R", "XYZCoordinates", "vars/System.html#XYZCoordinates"))
 aux2 = insFld(aux1, gFld("Species", "vars/System.html#System::Species"))
-insDoc(aux2, gLnk("R", "IonicInteraction", "vars/System.html#IonicInteraction"))
+insDoc(aux2, gLnk("R", "PseudopotentialAutomaticParameters", "vars/System.html#PseudopotentialAutomaticParameters"))
+insDoc(aux2, gLnk("R", "PseudopotentialEnergyTolerance", "vars/System.html#PseudopotentialEnergyTolerance"))
 insDoc(aux2, gLnk("R", "PseudopotentialSet", "vars/System.html#PseudopotentialSet"))
 insDoc(aux2, gLnk("R", "Species", "vars/System.html#Species"))
 insDoc(aux2, gLnk("R", "SpeciesProjectorSphereThreshold", "vars/System.html#SpeciesProjectorSphereThreshold"))
 insDoc(aux2, gLnk("R", "SpeciesTimeDependent", "vars/System.html#SpeciesTimeDependent"))
-aux2 = insFld(aux1, gFld("Subsystems", "vars/System.html#System::Subsystems"))
-insDoc(aux2, gLnk("R", "SubSystemCoordinates", "vars/System.html#SubSystemCoordinates"))
-insDoc(aux2, gLnk("R", "SubSystems", "vars/System.html#SubSystems"))
 aux2 = insFld(aux1, gFld("Velocities", "vars/System.html#System::Velocities"))
 insDoc(aux2, gLnk("R", "PDBVelocities", "vars/System.html#PDBVelocities"))
 insDoc(aux2, gLnk("R", "RandomVelocityTemp", "vars/System.html#RandomVelocityTemp"))
@@ -597,6 +584,7 @@ insDoc(aux2, gLnk("R", "PES_spm_points", "vars/Time-Dependent.html#PES_spm_point
 insDoc(aux2, gLnk("R", "PES_spm_recipe", "vars/Time-Dependent.html#PES_spm_recipe"))
 insDoc(aux2, gLnk("R", "PhotoElectronSpectrum", "vars/Time-Dependent.html#PhotoElectronSpectrum"))
 aux2 = insFld(aux1, gFld("Propagation", "vars/Time-Dependent.html#Time-Dependent::Propagation"))
+insDoc(aux2, gLnk("R", "ArnoldiOrthogonalization", "vars/Time-Dependent.html#ArnoldiOrthogonalization"))
 insDoc(aux2, gLnk("R", "IonsConstantVelocity", "vars/Time-Dependent.html#IonsConstantVelocity"))
 insDoc(aux2, gLnk("R", "IonsTimeDependentDisplacements", "vars/Time-Dependent.html#IonsTimeDependentDisplacements"))
 insDoc(aux2, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
@@ -702,11 +690,14 @@ insDoc(aux2, gLnk("R", "PropagationSpectrumEnergyStep", "vars/Utilities.html#Pro
 insDoc(aux2, gLnk("R", "PropagationSpectrumMaxEnergy", "vars/Utilities.html#PropagationSpectrumMaxEnergy"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumSigmaDiagonalization", "vars/Utilities.html#PropagationSpectrumSigmaDiagonalization"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#PropagationSpectrumStartTime"))
+insDoc(aux2, gLnk("R", "PropagationSpectrumSymmetrizeSigma", "vars/Utilities.html#PropagationSpectrumSymmetrizeSigma"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumTransform", "vars/Utilities.html#PropagationSpectrumTransform"))
 insDoc(aux2, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#PropagationSpectrumType"))
 insDoc(aux2, gLnk("R", "SpectrumMethod", "vars/Utilities.html#SpectrumMethod"))
 insDoc(aux2, gLnk("R", "SpectrumSignalNoise", "vars/Utilities.html#SpectrumSignalNoise"))
+insDoc(aux2, gLnk("R", "TransientAbsorptionReference", "vars/Utilities.html#TransientAbsorptionReference"))
 aux2 = insFld(aux1, gFld("oct-test", "vars/Utilities.html#Utilities::oct-test"))
+insDoc(aux2, gLnk("R", "TestHamiltonianApply", "vars/Utilities.html#TestHamiltonianApply"))
 insDoc(aux2, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
 insDoc(aux2, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
 insDoc(aux2, gLnk("R", "TestMode", "vars/Utilities.html#TestMode"))
