@@ -512,8 +512,13 @@ void FC_FUNC_(get_info_binary,GET_INFO_BINARY)
   fname_len = l1;
   io_read_header(hp, &correct_endianness, ierr, fname, fname_len);
 
-  *np  = hp->np;
-  *type = (int) hp->type;
+  if(*ierr == 0) {
+    *np  = hp->np;
+    *type = (int) hp->type;
+  } else {
+    *np = 0;
+    *type = TYPE_NONE;
+  }
   free(hp);
 
   TO_C_STR1(fname, filename);
